.. _service_module:

:mod:`fabtools.service`
-----------------------

.. automodule:: fabtools.service
    :members:

    .. seealso:: :ref:`require_service_module`
    .. seealso:: :ref:`systemd_module`
